#!/usr/bin/perl -w

use strict;
use warnings;
use Getopt::Std;
use patch_core;
use patch_actions;

sub usage()
{
    my $year = (localtime(time))[5] + 1900;
    print qq
{
 *  KSV Example Patch Installer
 *  Copyright (C) Kaspersky Lab 2003-$year

 *  This script install libvm_access.so patch as an example.
 *  If script failed to install the patch then the script
 *  rolls back all partial side effects that it has made.
 *  This script creates rollback.pl if patch applied successfully.
 *  It is finished with zero exit code if a patch applied successfully
 *  otherwise it is finished with non-zero exit code.

 *  install.pl [options] <patchdir>
 *  Command-line options:
 *      -h          Show help.
 *      <patchdir> - Path to a directory with extracted patch files.

}; exit(1);
}

our $prefix = 'patch install: ';
my %options;
getopt( 'h', \%options );
my $patchdir = $ARGV[0];
usage() if( !$patchdir || $options{"h"} );

my $actions = patch_actions->new( $patchdir );
eval
{
    $actions->ReplaceLink( { filename => "lightagent", filedir => "$productdir/bin" } );
    $actions->Commit();
};

$actions->Rollback( $@ ) if( $@ );
